About
-----

.. list-table::
   :stub-columns: 1

   * - project
     - |license|
   * - code
     - |travis| |coveralls| |black|
   * - pypi
     - |version| |supported-versions|

.. |travis| image:: https://travis-ci.org/alcarney/stylo.svg?branch=develop
   :target: https://travis-ci.org/alcarney/stylo

.. |coveralls| image:: https://coveralls.io/repos/github/alcarney/stylo/badge.svg?branch=develop
   :target: https://coveralls.io/github/alcarney/stylo?branch=develop

.. |black| image:: https://img.shields.io/badge/code%20style-black-000000.svg
   :target: https://github.com/ambv/black

.. |version| image:: https://img.shields.io/pypi/v/stylo.svg
   :alt: PyPI Package latest release
   :target: https://pypi.org/project/stylo

.. |supported-versions| image:: https://img.shields.io/pypi/pyversions/stylo.svg
   :alt: Supported versions
   :target: https://pypi.org/project/stylo

.. |license| image:: https://img.shields.io/github/license/alcarney/stylo.svg
   :alt: License


**DISCLAIMER!: Stylo is still in its early stages, many of the core
concepts are yet to be decided on. The interface can change without warning and
features may be added or removed without warning!**

Stylo is library that provides a number of tools that aim to make the process of creating
images and animations using nothing but some code and some mathematics possible. Since my
drawing abilities are very limited I created stylo as a way of me trying to close the gap
between my imagination and my artistic ability.

Installation
^^^^^^^^^^^^

Stylo is available on PyPi and can easily be installed using Pip:

.. code::

    $ pip install stylo

